@@ -15,7 +15,7 @@
   License along with this library; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  
-  $Id: castget.c,v 1.9 2006/03/21 00:13:09 mariuslj Exp $
+  $Id: castget.c,v 1.14 2006/06/09 22:36:11 mariuslj Exp $
   
 */
 
@@ -217,19 +217,23 @@ static void update_callback(void *user_data, libcastget_channel_action action,
       if (verbose) {
         if (enclosure->length > 1024*1024*1024) {
           g_printf(" * Downloading %s (%.1f GB) from %s\n", 
-                   enclosure->url, (float)enclosure->length / (1024.0*1024.0*1024.0), 
+                   enclosure->filename, (float)enclosure->length / (1024.0*1024.0*1024.0), 
                    channel_info->title);
         } else if (enclosure->length > 1024*1024) {
           g_printf(" * Downloading %s (%.1f MB) from %s\n", 
-                   enclosure->url, (float)enclosure->length / (1024.0*1024.0),
+                   enclosure->filename, (float)enclosure->length / (1024.0*1024.0),
                    channel_info->title);
         } else if (enclosure->length > 1024) {
           g_printf(" * Downloading %s (%.1f kB) from %s\n", 
-                   enclosure->url, (float)enclosure->length / 1024.0,
+                   enclosure->filename, (float)enclosure->length / 1024.0,
+                   channel_info->title);
+        } else if (enclosure->length > 0) {
+          g_printf(" * Downloading %s (%ld bytes) from %s\n", 
+                   enclosure->filename, enclosure->length,
                    channel_info->title);
         } else {
-          g_printf(" * Downloading %s (%ld bytes) from %s\n", 
-                   enclosure->url, enclosure->length,
+          g_printf(" * Downloading %s from %s\n",
+                   enclosure->filename,
                    channel_info->title);
         }
       }
@@ -241,7 +245,7 @@ static void update_callback(void *user_data, libcastget_channel_action action,
       g_assert(filename);
 
       /* Set media tags. */
-      if (!strcmp(enclosure->type, "audio/mpeg")) {
+      if (enclosure->type && !strcmp(enclosure->type, "audio/mpeg")) {
 #ifdef ENABLE_ID3LIB
         _id3_check_and_set(filename, c);
 #endif /* ENABLE_ID3LIB */
@@ -298,9 +302,8 @@ static void list_callback(void *user_data, libcastget_channel_action action, lib
       g_assert(channel_info);
       g_assert(enclosure);
 
-      if (verbose)
-        g_printf("* %s (%ld bytes) from %s\n", enclosure->url, enclosure->length, 
-                 channel_info->title);
+      g_printf("* %s (%ld bytes) from %s\n", enclosure->url, enclosure->length, 
+               channel_info->title);
       break;
     }
   }
@@ -349,7 +352,6 @@ static int _process_channel(const gchar *channel_directory, GKeyFile *kf, const
   if (!c) {
     fprintf(stderr, "Error parsing channel file for channel %s.\n", identifier);
 
-    libcastget_channel_free(c);
     channel_configuration_free(channel_configuration);
     return -1;
   }
@@ -384,7 +386,8 @@ static GKeyFile *_configuration_file_open(void)
   rcfile = g_build_filename(g_get_home_dir(), ".castgetrc", NULL);
 
   if (!g_key_file_load_from_file(kf, rcfile, G_KEY_FILE_NONE, &error)) {
-    fprintf(stderr, "Configuration file %s not found.\n", rcfile);
+    fprintf(stderr, "Error reading configuration file %s: %s.\n", rcfile, error->message);
+    g_error_free(error);
     g_key_file_free(kf);
     kf = NULL;
   }
@@ -447,49 +450,49 @@ static int _id3_set(const gchar *filename, int clear, const gchar *lead_artist,
     errors += _id3_find_and_set_frame(tag, ID3FID_LEADARTIST, lead_artist);
 
     if (verbose)
-      printf("Set ID3 tag lead artist to %s.\n", lead_artist);
+      printf(" * Set ID3 tag lead artist to %s.\n", lead_artist);
   }
 
   if (content_group) {
     errors += _id3_find_and_set_frame(tag, ID3FID_CONTENTGROUP, content_group);
 
     if (verbose)
-      printf("Set ID3 tag content group to %s.\n", content_group);
+      printf(" * Set ID3 tag content group to %s.\n", content_group);
   }
 
   if (title) {
     errors += _id3_find_and_set_frame(tag, ID3FID_TITLE, title);
 
     if (verbose)
-      printf("Set ID3 tag title to %s.\n", title);
+      printf(" * Set ID3 tag title to %s.\n", title);
   }
 
   if (album) {
     errors += _id3_find_and_set_frame(tag, ID3FID_ALBUM, album);
 
     if (verbose)
-      printf("Set ID3 tag album to %s.\n", album);
+      printf(" * Set ID3 tag album to %s.\n", album);
   }
 
   if (content_type) {
     errors += _id3_find_and_set_frame(tag, ID3FID_CONTENTTYPE, content_type);
 
     if (verbose)
-      printf("Set ID3 tag content type to %s.\n", content_type);
+      printf(" * Set ID3 tag content type to %s.\n", content_type);
   }
 
   if (year) {
     errors += _id3_find_and_set_frame(tag, ID3FID_YEAR, year);
 
     if (verbose)
-      printf("Set ID3 title year to %s.\n", year);
+      printf(" * Set ID3 title year to %s.\n", year);
   }
 
   if (comment) {
     errors += _id3_find_and_set_frame(tag, ID3FID_COMMENT, comment);
 
     if (verbose)
-      printf("Set ID3 tag comment to %s.\n", comment);
+      printf(" * Set ID3 tag comment to %s.\n", comment);
   }
 
   if (!errors)
